@@ -34,8 +34,22 @@ class Mesh(BaseMesh):
     Examples
     --------
     >>> mesh = Mesh.from_polyhedron(6)
+
     """
-    bounding_box = mesh_bounding_box
+
+    def bounding_box(self):
+        """Compute the axis-aligned bounding box of the mesh.
+
+        Returns
+        -------
+        box: tuple of 8 points.
+            The corners of the bounding box.
+            The first 4 points are the corners of the bottom face, in counter clockwise direction wrt the positive Z-axis.
+            The last 4 points are the corners of the top face, in counter clockwise direction wrt the positive Z-axis.
+
+        """
+        return mesh_bounding_box(self)
+
     bounding_box_xy = mesh_bounding_box_xy
     collapse_edge = mesh_collapse_edge
     connected_components = mesh_connected_components
@@ -55,10 +69,6 @@ class Mesh(BaseMesh):
     unify_cycles = mesh_unify_cycles
     quads_to_triangles = mesh_quads_to_triangles
 
-    def transform_numpy(self, M):
-        from compas.datastructures.mesh.transformations_numpy import mesh_transform_numpy
-        mesh_transform_numpy(self, M)
-
 
 # =============================================================================
 # Main
